
/*
    xskat - a card game for 1 to 3 players.
    Copyright (C) 1997  Gunter Gerhardt

    This program is free software; you can redistribute it freely.
    Use it at your own risk; there is NO WARRANTY.
*/

#define static
#include "icon.xbm"
#include "bwcards.xbm"
#include "bwcardl.xbm"
#include "colcards.xbm"
#include "colcardl.xbm"
char colcards_pixs[colcards_width*colcards_height/4];
char colcardl_pixs[colcardl_width*colcardl_height/4];
